@@ -48,7 +48,7 @@ class SyncClient(object):
             if app_name is not None:
                 headers["X-App-Name"] = app_name
 
-        self.sender = self.sender_class(base_url=None, proxy_url=proxy_url, headers=headers)
+        self.sender = self.sender_class(base_url=base_url, proxy_url=proxy_url, headers=headers)
         self.accumulator = self.accumulator_class(
             max_batch_size=max_batch_size, linger_time=interval_batch)
         self.executor = ThreadPoolExecutor(max_workers=self.max_workers)
@@ -80,15 +80,19 @@ class SyncClient(object):
         if batch:
             self.executor.submit(self.sender.send_batch, batch)
 
-    def flush(self, soft=False):  # type: (bool) -> None
+    def flush(self, soft=False, sync=False):  # type: (bool, bool) -> None
         """Send all pending signals and traces.
 
         :param soft: (optional) Do not send the batch if it has not exceeded
         the interval time.
+        :param sync: (optional) Wait for the batch to be transmitted.
         """
         batch = self.accumulator.flush(soft=soft)
         if batch:
-            self.executor.submit(self.sender.send_batch, batch)
+            if sync:
+                self.sender.send_batch(batch)
+            else:
+                self.executor.submit(self.sender.send_batch, batch)
 
     def close(self):  # type: () -> None
         """Close the client.
